summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/managedconnectionaccount.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/libkopete/managedconnectionaccount.h')
-rw-r--r--kopete/libkopete/managedconnectionaccount.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kopete/libkopete/managedconnectionaccount.h b/kopete/libkopete/managedconnectionaccount.h
index 1de3a7ad..a27bd7cd 100644
--- a/kopete/libkopete/managedconnectionaccount.h
+++ b/kopete/libkopete/managedconnectionaccount.h
@@ -40,12 +40,12 @@ class KOPETE_EXPORT ManagedConnectionAccount : public PasswordedAccount
public:
/**
* @brief ManagedConnectionAccount constructor.
* @param tqparent The protocol this account connects via
* @param acctId The ID of this account - should be unique within this protocol
* @param maxPasswordLength The maximum length for passwords for this account, or 0 for no limit
* @param name The name for this TQObject
*/
- ManagedConnectionAccount( Protocol *tqparent, const TQString &acctId, uint maxPasswordLength = 0, const char *name = 0 );
+ ManagedConnectionAccount( Protocol *parent, const TQString &acctId, uint maxPasswordLength = 0, const char *name = 0 );
public slots:
/**
* @brief Begin the connection process, by checking if the connection is available with the ConnectionManager.
@@ -40,12 +40,12 @@ class KOPETE_EXPORT ManagedConnectionAccount : public PasswordedAccount
/**
* @brief ManagedConnectionAccount constructor.
- * @param tqparent The protocol this account connects via
+ * @param parent The protocol this account connects via
* @param acctId The ID of this account - should be unique within this protocol
* @param maxPasswordLength The maximum length for passwords for this account, or 0 for no limit